%Main run that computes prior performance on 24 Kodak Images
close all;
clear all;

numimages = 24;
c_gaussian = fspecial('gaussian', [12 12], 5);
c_motion = fspecial('motion', 20, 0);
c_average = fspecial('average', [9 9]);

%choose blur kernel and noise statistic;
c = c_gaussian; %c_gaussian,c_average
s_noise = 0.01;

%Main loop through all images
for i = 1:numimages
    %import image
    I = im2double(imread(strcat('kodim0',num2str(i+10),'.png')));
    I = rgb2gray(I);
    I = I(1:2:end,1:2:end);
    imshow(I)
    
    %corrupt images
    Ib = ifft2(fft2(I) .* psf2otf(c,size(I)));
    b = Ib + s_noise*randn(size(I));
    imshow(b);
    lambda_opt = lambdaopt(b,c,I);
    
    %store psnr of corrupted image
    psnr_b(:,i) = [psnr(b,I);ssim(b,I)];
    
    %TV
    lambda = lambda_opt(1);
    [x,time,performance,convergence] = deblur(b,c,I,'TV',lambda);
    psnr_tv(:,i) = performance(:,end);
    time_tv(:,i) = time;
    
    %TV isotropic
    [x,time,performance,convergence] = deblur(b,c,I,'TVi',lambda);
    psnr_tvi(:,i) = performance(:,end);
    time_tvi(:,i) = time;
    
    %Laplacian kernel 1
    lambda = lambda_opt(2);
    [x,time,performance,convergence] = deblur(b,c,I,'Lap1',lambda);
    psnr_l1(:,i) = performance(:,end);
    time_l1(:,i) = time;
    
    %Laplacian kernel 2
    [x,time,performance,convergence] = deblur(b,c,I,'Lap1',lambda);
    psnr_l2(:,i) = performance(:,end);
    time_l2(:,i) = time;
    
    %Frobenius norm of Hessian
    lambda = lambda_opt(3);
    [x,time,performance,convergence] = deblur(b,c,I,'Fro',lambda);
    psnr_f(:,i) = performance(:,end);
    time_f(:,i) = time;
end

%Outputs all the data!
psnr_b
psnr_tv
psnr_tvi
psnr_l1
psnr_l2
psnr_f

time_tv
time_tvi
time_l1
time_l2
time_f


