%Runs all the priors on a single test image

close all;
clear all;
I = im2double(imread('gordon.jpg'));
I = rgb2gray(I);

%Blur kernels
c_gaussian = fspecial('gaussian', [10 10], 5);
c_motion = fspecial('motion', 20, 0);
c_average = fspecial('average', [9 9]);

%choose blur kernel
c = c_average; %c_gaussian,c_average

%corrupted image
Ib = ifft2(fft2(I) .* psf2otf(c,size(I)));
b = Ib + 0.05*randn(size(I));
imshow(b);

%TV Prior
lambda = 0.01;
[x_tv,t_tv,p_tv,c_tv] = deblur(b,c,I,'TV',lambda);
figure;
imshow(x_tv);

%Laplacian Prior
lambda = 0.01;
[x_l,t_l,p_l,c_l] = deblur(b,c,I,'Lap1',lambda);
figure;
imshow(x_l);

%Frobenius of Hessian Prior
lambda = 50;
[x_fr,t_fr,p_fr,c_fr] = deblur(b,c,I,'Fro',1/lambda);
figure;
imshow(x_fr);

%Display Perfomance metrics and Convergence
figure;
hold on
plot(t_tv,c_tv,'DisplayName','TV');
plot(t_l,c_l,'DisplayName','Laplacian');
plot(t_fr,c_fr,'DisplayName','Frobenius');
xlabel('time(s)');
ylabel('convergence(next step - previous step)');
legend show

figure;
hold on
plot(1:length(t_tv),p_tv(1,:),'DisplayName','TV');
plot(1:length(t_l),p_l(1,:),'DisplayName','Laplacian');
plot(1:length(t_fr),p_fr(1,:),'DisplayName','Frobenius');
xlabel('Iteration');
ylabel('PSNR(dB)');
legend show

figure;
hold on
plot(1:length(t_tv),p_tv(2,:),'DisplayName','TV');
plot(1:length(t_l),p_l(2,:),'DisplayName','Laplacian');
plot(1:length(t_fr),p_fr(2,:),'DisplayName','Frobenius');
legend show
xlabel('Iteration');
ylabel('SSIM');

