function [x,runtime,performance,convergence] = deblur(b,c,Iref,prior,lambda)
%General deblurrer for non-blind deconvolution,
%Inputs:
%   b - blurred image
%   c - blur kernel
%   prior - image prior
%        ('TV'(anisotropic),'TVi'(isotropic),'Lap1','Lap2','Fro')
%   lambda - amount of weighting on the prior
%Output
%   estimated image
%   Runtime
%   Performance [ PSNR, SSIM]
%   Convergence Vector

if(strcmp('TV',prior))
    [x,convergence,time,performance] = admm_lasso(b,c,Iref,lambda,prior,'Simple');
elseif(strcmp('TVi',prior))
    [x,convergence,time,performance] = admm_lasso(b,c,Iref,lambda,prior,'Simple');  
elseif(strcmp('Lap1',prior))
    [x,convergence,time,performance] = admm_lasso(b,c,Iref,lambda,'Lap','Simple');    
elseif(strcmp('Lap2',prior))
    [x,convergence,time,performance] = admm_lasso(b,c,Iref,lambda,'Lap','Diagonals');
elseif(strcmp('Fro',prior))
    [x,convergence,time,performance] = admm_fr(b,c,Iref,1/lambda); 
else
    x = b;
    convergence = [];
    fprintf('No supported prior was specified, original image was returned\n')
    time = 0;  
end
%performance = [psnr(x,Iref);ssim(x,Iref)];
runtime = time;%[time;iter];
end

